#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   Issue #350 is still open: on Windows, the code here causes it to link
   with PYTHON36.DLL (for example) instead of PYTHON3.DLL.  A fix was
   attempted in 164e526a5515 and 14ce6985e1c3, but reverted: virtualenv
   does not make PYTHON3.DLL available, and so the "correctly" compiled
   version would not run inside a virtualenv.  We will re-apply the fix
   after virtualenv has been fixed for some time.  For explanation, see
   issue #355.  For a workaround if you want PYTHON3.DLL and don't worry
   about virtualenv, see issue #350.  See also 'py_limited_api' in
   setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  include <pyconfig.h>
#  if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG)
#    define Py_LIMITED_API
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t(x);
}


/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

#include "hoedown/buffer.h"
#include "hoedown/document.h"
#include "hoedown/escape.h"
#include "hoedown/html.h"
#include "extra.h"


/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 16), // hoedown_buffer *()(size_t)
/*  1 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 125), // hoedown_document *()(hoedown_renderer const *, hoedown_extensions, size_t)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 143), // hoedown_renderer const *
/*  5 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // hoedown_extensions
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION, 134), // hoedown_renderer *()(hoedown_html_flags, int)
/*  9 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // hoedown_html_flags
/* 10 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION, 134), // hoedown_renderer *()(int)
/* 13 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // int()(hoedown_buffer *, hoedown_buffer const *, hoedown_autolink_type, hoedown_renderer_data const *)
/* 16 */ _CFFI_OP(_CFFI_OP_POINTER, 140), // hoedown_buffer *
/* 17 */ _CFFI_OP(_CFFI_OP_POINTER, 140), // hoedown_buffer const *
/* 18 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // hoedown_autolink_type
/* 19 */ _CFFI_OP(_CFFI_OP_POINTER, 144), // hoedown_renderer_data const *
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // int()(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 22 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 23 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 24 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 25 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 26 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 28 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // int()(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 29 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 30 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 31 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // int()(hoedown_buffer *, hoedown_buffer const *, int, hoedown_renderer_data const *)
/* 34 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 35 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 36 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 37 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 38 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // int()(hoedown_buffer *, hoedown_renderer_data const *)
/* 40 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 41 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // int()(hoedown_buffer *, unsigned int, hoedown_renderer_data const *)
/* 44 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 45 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 46 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 48 */ _CFFI_OP(_CFFI_OP_FUNCTION, 55), // void *()(hoedown_renderer_data const *)
/* 49 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 51 */ _CFFI_OP(_CFFI_OP_FUNCTION, 55), // void *()(size_t)
/* 52 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 55), // void *()(void *, size_t)
/* 55 */ _CFFI_OP(_CFFI_OP_POINTER, 163), // void *
/* 56 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *)
/* 59 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 60 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, char const *)
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 63 */ _CFFI_OP(_CFFI_OP_POINTER, 139), // char const *
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 66 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 67 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 68 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 69 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 70 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 71 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_buffer const *, hoedown_list_flags, hoedown_renderer_data const *)
/* 72 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 73 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 74 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // hoedown_list_flags
/* 75 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 76 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 77 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 78 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 79 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 80 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 81 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_buffer const *, hoedown_table_flags, hoedown_renderer_data const *)
/* 83 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 84 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 85 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // hoedown_table_flags
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_buffer const *, int, hoedown_renderer_data const *)
/* 89 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 90 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 91 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 92 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_buffer const *, unsigned int, hoedown_renderer_data const *)
/* 95 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 96 */ _CFFI_OP(_CFFI_OP_NOOP, 17),
/* 97 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 98 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 99 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 100 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, hoedown_renderer_data const *)
/* 101 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 102 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 103 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 104 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, int, hoedown_renderer_data const *)
/* 105 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 106 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 107 */ _CFFI_OP(_CFFI_OP_NOOP, 19),
/* 108 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, size_t)
/* 110 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 111 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 112 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 113 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, uint8_t const *, size_t)
/* 114 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 115 */ _CFFI_OP(_CFFI_OP_POINTER, 152), // uint8_t const *
/* 116 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 117 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_buffer *, uint8_t const *, size_t, int)
/* 119 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 120 */ _CFFI_OP(_CFFI_OP_NOOP, 115),
/* 121 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 122 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 123 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 124 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_document *)
/* 125 */ _CFFI_OP(_CFFI_OP_POINTER, 141), // hoedown_document *
/* 126 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 127 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_document *, hoedown_buffer *, uint8_t const *, size_t)
/* 128 */ _CFFI_OP(_CFFI_OP_NOOP, 125),
/* 129 */ _CFFI_OP(_CFFI_OP_NOOP, 16),
/* 130 */ _CFFI_OP(_CFFI_OP_NOOP, 115),
/* 131 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(hoedown_renderer *)
/* 134 */ _CFFI_OP(_CFFI_OP_POINTER, 143), // hoedown_renderer *
/* 135 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 136 */ _CFFI_OP(_CFFI_OP_FUNCTION, 163), // void()(void *)
/* 137 */ _CFFI_OP(_CFFI_OP_NOOP, 55),
/* 138 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 139 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 140 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // hoedown_buffer
/* 141 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // hoedown_document
/* 142 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // hoedown_html_tag
/* 143 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // hoedown_renderer
/* 144 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // hoedown_renderer_data
/* 145 */ _CFFI_OP(_CFFI_OP_POINTER, 15), // int(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_autolink_type, hoedown_renderer_data const *)
/* 146 */ _CFFI_OP(_CFFI_OP_POINTER, 21), // int(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 147 */ _CFFI_OP(_CFFI_OP_POINTER, 28), // int(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 148 */ _CFFI_OP(_CFFI_OP_POINTER, 33), // int(*)(hoedown_buffer *, hoedown_buffer const *, int, hoedown_renderer_data const *)
/* 149 */ _CFFI_OP(_CFFI_OP_POINTER, 39), // int(*)(hoedown_buffer *, hoedown_renderer_data const *)
/* 150 */ _CFFI_OP(_CFFI_OP_POINTER, 43), // int(*)(hoedown_buffer *, unsigned int, hoedown_renderer_data const *)
/* 151 */ _CFFI_OP(_CFFI_OP_POINTER, 152), // uint8_t *
/* 152 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 18), // uint8_t
/* 153 */ _CFFI_OP(_CFFI_OP_POINTER, 54), // void *(*)(void *, size_t)
/* 154 */ _CFFI_OP(_CFFI_OP_POINTER, 65), // void(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 155 */ _CFFI_OP(_CFFI_OP_POINTER, 71), // void(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_list_flags, hoedown_renderer_data const *)
/* 156 */ _CFFI_OP(_CFFI_OP_POINTER, 77), // void(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *)
/* 157 */ _CFFI_OP(_CFFI_OP_POINTER, 82), // void(*)(hoedown_buffer *, hoedown_buffer const *, hoedown_table_flags, hoedown_renderer_data const *)
/* 158 */ _CFFI_OP(_CFFI_OP_POINTER, 88), // void(*)(hoedown_buffer *, hoedown_buffer const *, int, hoedown_renderer_data const *)
/* 159 */ _CFFI_OP(_CFFI_OP_POINTER, 94), // void(*)(hoedown_buffer *, hoedown_buffer const *, unsigned int, hoedown_renderer_data const *)
/* 160 */ _CFFI_OP(_CFFI_OP_POINTER, 100), // void(*)(hoedown_buffer *, hoedown_renderer_data const *)
/* 161 */ _CFFI_OP(_CFFI_OP_POINTER, 104), // void(*)(hoedown_buffer *, int, hoedown_renderer_data const *)
/* 162 */ _CFFI_OP(_CFFI_OP_POINTER, 136), // void(*)(void *)
/* 163 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_HOEDOWN_AUTOLINK_NONE(unsigned long long *o)
{
  int n = (HOEDOWN_AUTOLINK_NONE) <= 0;
  *o = (unsigned long long)((HOEDOWN_AUTOLINK_NONE) | 0);  /* check that HOEDOWN_AUTOLINK_NONE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_AUTOLINK_NORMAL(unsigned long long *o)
{
  int n = (HOEDOWN_AUTOLINK_NORMAL) <= 0;
  *o = (unsigned long long)((HOEDOWN_AUTOLINK_NORMAL) | 0);  /* check that HOEDOWN_AUTOLINK_NORMAL is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_AUTOLINK_EMAIL(unsigned long long *o)
{
  int n = (HOEDOWN_AUTOLINK_EMAIL) <= 0;
  *o = (unsigned long long)((HOEDOWN_AUTOLINK_EMAIL) | 0);  /* check that HOEDOWN_AUTOLINK_EMAIL is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_TABLES(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_TABLES) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_TABLES) | 0);  /* check that HOEDOWN_EXT_TABLES is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_FENCED_CODE(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_FENCED_CODE) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_FENCED_CODE) | 0);  /* check that HOEDOWN_EXT_FENCED_CODE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_FOOTNOTES(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_FOOTNOTES) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_FOOTNOTES) | 0);  /* check that HOEDOWN_EXT_FOOTNOTES is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_AUTOLINK(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_AUTOLINK) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_AUTOLINK) | 0);  /* check that HOEDOWN_EXT_AUTOLINK is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_STRIKETHROUGH(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_STRIKETHROUGH) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_STRIKETHROUGH) | 0);  /* check that HOEDOWN_EXT_STRIKETHROUGH is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_UNDERLINE(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_UNDERLINE) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_UNDERLINE) | 0);  /* check that HOEDOWN_EXT_UNDERLINE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_HIGHLIGHT(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_HIGHLIGHT) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_HIGHLIGHT) | 0);  /* check that HOEDOWN_EXT_HIGHLIGHT is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_QUOTE(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_QUOTE) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_QUOTE) | 0);  /* check that HOEDOWN_EXT_QUOTE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_SUPERSCRIPT(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_SUPERSCRIPT) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_SUPERSCRIPT) | 0);  /* check that HOEDOWN_EXT_SUPERSCRIPT is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_MATH(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_MATH) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_MATH) | 0);  /* check that HOEDOWN_EXT_MATH is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_NO_INTRA_EMPHASIS(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_NO_INTRA_EMPHASIS) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_NO_INTRA_EMPHASIS) | 0);  /* check that HOEDOWN_EXT_NO_INTRA_EMPHASIS is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_SPACE_HEADERS(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_SPACE_HEADERS) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_SPACE_HEADERS) | 0);  /* check that HOEDOWN_EXT_SPACE_HEADERS is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_MATH_EXPLICIT(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_MATH_EXPLICIT) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_MATH_EXPLICIT) | 0);  /* check that HOEDOWN_EXT_MATH_EXPLICIT is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_EXT_DISABLE_INDENTED_CODE(unsigned long long *o)
{
  int n = (HOEDOWN_EXT_DISABLE_INDENTED_CODE) <= 0;
  *o = (unsigned long long)((HOEDOWN_EXT_DISABLE_INDENTED_CODE) | 0);  /* check that HOEDOWN_EXT_DISABLE_INDENTED_CODE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_SKIP_HTML(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_SKIP_HTML) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_SKIP_HTML) | 0);  /* check that HOEDOWN_HTML_SKIP_HTML is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_ESCAPE(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_ESCAPE) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_ESCAPE) | 0);  /* check that HOEDOWN_HTML_ESCAPE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_HARD_WRAP(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_HARD_WRAP) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_HARD_WRAP) | 0);  /* check that HOEDOWN_HTML_HARD_WRAP is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_USE_XHTML(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_USE_XHTML) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_USE_XHTML) | 0);  /* check that HOEDOWN_HTML_USE_XHTML is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_TAG_NONE(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_TAG_NONE) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_TAG_NONE) | 0);  /* check that HOEDOWN_HTML_TAG_NONE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_TAG_OPEN(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_TAG_OPEN) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_TAG_OPEN) | 0);  /* check that HOEDOWN_HTML_TAG_OPEN is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_HTML_TAG_CLOSE(unsigned long long *o)
{
  int n = (HOEDOWN_HTML_TAG_CLOSE) <= 0;
  *o = (unsigned long long)((HOEDOWN_HTML_TAG_CLOSE) | 0);  /* check that HOEDOWN_HTML_TAG_CLOSE is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_LIST_ORDERED(unsigned long long *o)
{
  int n = (HOEDOWN_LIST_ORDERED) <= 0;
  *o = (unsigned long long)((HOEDOWN_LIST_ORDERED) | 0);  /* check that HOEDOWN_LIST_ORDERED is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_LI_BLOCK(unsigned long long *o)
{
  int n = (HOEDOWN_LI_BLOCK) <= 0;
  *o = (unsigned long long)((HOEDOWN_LI_BLOCK) | 0);  /* check that HOEDOWN_LI_BLOCK is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_TABLE_ALIGN_LEFT(unsigned long long *o)
{
  int n = (HOEDOWN_TABLE_ALIGN_LEFT) <= 0;
  *o = (unsigned long long)((HOEDOWN_TABLE_ALIGN_LEFT) | 0);  /* check that HOEDOWN_TABLE_ALIGN_LEFT is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_TABLE_ALIGN_RIGHT(unsigned long long *o)
{
  int n = (HOEDOWN_TABLE_ALIGN_RIGHT) <= 0;
  *o = (unsigned long long)((HOEDOWN_TABLE_ALIGN_RIGHT) | 0);  /* check that HOEDOWN_TABLE_ALIGN_RIGHT is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_TABLE_ALIGN_CENTER(unsigned long long *o)
{
  int n = (HOEDOWN_TABLE_ALIGN_CENTER) <= 0;
  *o = (unsigned long long)((HOEDOWN_TABLE_ALIGN_CENTER) | 0);  /* check that HOEDOWN_TABLE_ALIGN_CENTER is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_TABLE_ALIGNMASK(unsigned long long *o)
{
  int n = (HOEDOWN_TABLE_ALIGNMASK) <= 0;
  *o = (unsigned long long)((HOEDOWN_TABLE_ALIGNMASK) | 0);  /* check that HOEDOWN_TABLE_ALIGNMASK is an integer */
  return n;
}

static int _cffi_const_HOEDOWN_TABLE_HEADER(unsigned long long *o)
{
  int n = (HOEDOWN_TABLE_HEADER) <= 0;
  *o = (unsigned long long)((HOEDOWN_TABLE_HEADER) | 0);  /* check that HOEDOWN_TABLE_HEADER is an integer */
  return n;
}

static void _cffi_d_hoedown_buffer_free(hoedown_buffer * x0)
{
  hoedown_buffer_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_buffer_free(PyObject *self, PyObject *arg0)
{
  hoedown_buffer * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_buffer *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_buffer_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_buffer_free _cffi_d_hoedown_buffer_free
#endif

static void _cffi_d_hoedown_buffer_grow(hoedown_buffer * x0, size_t x1)
{
  hoedown_buffer_grow(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_buffer_grow(PyObject *self, PyObject *args)
{
  hoedown_buffer * x0;
  size_t x1;
  Py_ssize_t datasize;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "hoedown_buffer_grow", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_buffer *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_buffer_grow(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_buffer_grow _cffi_d_hoedown_buffer_grow
#endif

static hoedown_buffer * _cffi_d_hoedown_buffer_new(size_t x0)
{
  return hoedown_buffer_new(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_buffer_new(PyObject *self, PyObject *arg0)
{
  size_t x0;
  hoedown_buffer * result;

  x0 = _cffi_to_c_int(arg0, size_t);
  if (x0 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = hoedown_buffer_new(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(16));
}
#else
#  define _cffi_f_hoedown_buffer_new _cffi_d_hoedown_buffer_new
#endif

static void _cffi_d_hoedown_buffer_puts(hoedown_buffer * x0, char const * x1)
{
  hoedown_buffer_puts(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_buffer_puts(PyObject *self, PyObject *args)
{
  hoedown_buffer * x0;
  char const * x1;
  Py_ssize_t datasize;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "hoedown_buffer_puts", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_buffer *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(63), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(63), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_buffer_puts(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_buffer_puts _cffi_d_hoedown_buffer_puts
#endif

static void _cffi_d_hoedown_document_free(hoedown_document * x0)
{
  hoedown_document_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_document_free(PyObject *self, PyObject *arg0)
{
  hoedown_document * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(125), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_document *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(125), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_document_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_document_free _cffi_d_hoedown_document_free
#endif

static hoedown_document * _cffi_d_hoedown_document_new(hoedown_renderer const * x0, hoedown_extensions x1, size_t x2)
{
  return hoedown_document_new(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_document_new(PyObject *self, PyObject *args)
{
  hoedown_renderer const * x0;
  hoedown_extensions x1;
  size_t x2;
  Py_ssize_t datasize;
  hoedown_document * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "hoedown_document_new", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_renderer const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(5), arg1) < 0)
    return NULL;

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = hoedown_document_new(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(125));
}
#else
#  define _cffi_f_hoedown_document_new _cffi_d_hoedown_document_new
#endif

static void _cffi_d_hoedown_document_render(hoedown_document * x0, hoedown_buffer * x1, uint8_t const * x2, size_t x3)
{
  hoedown_document_render(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_document_render(PyObject *self, PyObject *args)
{
  hoedown_document * x0;
  hoedown_buffer * x1;
  uint8_t const * x2;
  size_t x3;
  Py_ssize_t datasize;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "hoedown_document_render", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(125), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_document *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(125), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (hoedown_buffer *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(16), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(115), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (uint8_t const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(115), arg2) < 0)
      return NULL;
  }

  x3 = _cffi_to_c_int(arg3, size_t);
  if (x3 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_document_render(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_document_render _cffi_d_hoedown_document_render
#endif

static void _cffi_d_hoedown_escape_html(hoedown_buffer * x0, uint8_t const * x1, size_t x2, int x3)
{
  hoedown_escape_html(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_escape_html(PyObject *self, PyObject *args)
{
  hoedown_buffer * x0;
  uint8_t const * x1;
  size_t x2;
  int x3;
  Py_ssize_t datasize;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;

  if (!PyArg_UnpackTuple(args, "hoedown_escape_html", 4, 4, &arg0, &arg1, &arg2, &arg3))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_buffer *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(115), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (uint8_t const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(115), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_escape_html(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_escape_html _cffi_d_hoedown_escape_html
#endif

static void _cffi_d_hoedown_html_renderer_free(hoedown_renderer * x0)
{
  hoedown_html_renderer_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_html_renderer_free(PyObject *self, PyObject *arg0)
{
  hoedown_renderer * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(134), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_renderer *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(134), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_html_renderer_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_html_renderer_free _cffi_d_hoedown_html_renderer_free
#endif

static hoedown_renderer * _cffi_d_hoedown_html_renderer_new(hoedown_html_flags x0, int x1)
{
  return hoedown_html_renderer_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_html_renderer_new(PyObject *self, PyObject *args)
{
  hoedown_html_flags x0;
  int x1;
  hoedown_renderer * result;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "hoedown_html_renderer_new", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(9), arg0) < 0)
    return NULL;

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = hoedown_html_renderer_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(134));
}
#else
#  define _cffi_f_hoedown_html_renderer_new _cffi_d_hoedown_html_renderer_new
#endif

static void _cffi_d_hoedown_html_smartypants(hoedown_buffer * x0, uint8_t const * x1, size_t x2)
{
  hoedown_html_smartypants(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_html_smartypants(PyObject *self, PyObject *args)
{
  hoedown_buffer * x0;
  uint8_t const * x1;
  size_t x2;
  Py_ssize_t datasize;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "hoedown_html_smartypants", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(16), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_buffer *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(16), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(115), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (uint8_t const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(115), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, size_t);
  if (x2 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { hoedown_html_smartypants(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_hoedown_html_smartypants _cffi_d_hoedown_html_smartypants
#endif

static hoedown_renderer * _cffi_d_hoedown_html_toc_renderer_new(int x0)
{
  return hoedown_html_toc_renderer_new(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_html_toc_renderer_new(PyObject *self, PyObject *arg0)
{
  int x0;
  hoedown_renderer * result;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = hoedown_html_toc_renderer_new(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(134));
}
#else
#  define _cffi_f_hoedown_html_toc_renderer_new _cffi_d_hoedown_html_toc_renderer_new
#endif

static void * _cffi_d_hoedown_malloc(size_t x0)
{
  return hoedown_malloc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_hoedown_malloc(PyObject *self, PyObject *arg0)
{
  size_t x0;
  void * result;

  x0 = _cffi_to_c_int(arg0, size_t);
  if (x0 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = hoedown_malloc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(55));
}
#else
#  define _cffi_f_hoedown_malloc _cffi_d_hoedown_malloc
#endif

static void * _cffi_d_misaka_get_renderer(hoedown_renderer_data const * x0)
{
  return misaka_get_renderer(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_misaka_get_renderer(PyObject *self, PyObject *arg0)
{
  hoedown_renderer_data const * x0;
  Py_ssize_t datasize;
  void * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(19), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (hoedown_renderer_data const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(19), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = misaka_get_renderer(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(55));
}
#else
#  define _cffi_f_misaka_get_renderer _cffi_d_misaka_get_renderer
#endif

_CFFI_UNUSED_FN
static void _cffi_checkfld__hoedown_buffer(hoedown_buffer *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { uint8_t * *tmp = &p->data; (void)tmp; }
  (void)((p->size) | 0);  /* check that 'hoedown_buffer.size' is an integer */
  (void)((p->asize) | 0);  /* check that 'hoedown_buffer.asize' is an integer */
  (void)((p->unit) | 0);  /* check that 'hoedown_buffer.unit' is an integer */
  { void *(* *tmp)(void *, size_t) = &p->data_realloc; (void)tmp; }
  { void(* *tmp)(void *) = &p->data_free; (void)tmp; }
  { void(* *tmp)(void *) = &p->buffer_free; (void)tmp; }
}
struct _cffi_align__hoedown_buffer { char x; hoedown_buffer y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__hoedown_renderer(hoedown_renderer *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->opaque; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->blockcode; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->blockquote; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, int, hoedown_renderer_data const *) = &p->header; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_renderer_data const *) = &p->hrule; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_list_flags, hoedown_renderer_data const *) = &p->list; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_list_flags, hoedown_renderer_data const *) = &p->listitem; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->paragraph; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->table; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->table_header; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->table_body; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->table_row; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_table_flags, hoedown_renderer_data const *) = &p->table_cell; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->footnotes; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, unsigned int, hoedown_renderer_data const *) = &p->footnote_def; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->blockhtml; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_autolink_type, hoedown_renderer_data const *) = &p->autolink; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->codespan; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->double_emphasis; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->emphasis; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->underline; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->highlight; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->quote; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->image; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_renderer_data const *) = &p->linebreak; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_buffer const *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->link; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->triple_emphasis; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->strikethrough; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->superscript; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, unsigned int, hoedown_renderer_data const *) = &p->footnote_ref; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, int, hoedown_renderer_data const *) = &p->math; (void)tmp; }
  { int(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->raw_html; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->entity; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, hoedown_buffer const *, hoedown_renderer_data const *) = &p->normal_text; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, int, hoedown_renderer_data const *) = &p->doc_header; (void)tmp; }
  { void(* *tmp)(hoedown_buffer *, int, hoedown_renderer_data const *) = &p->doc_footer; (void)tmp; }
}
struct _cffi_align__hoedown_renderer { char x; hoedown_renderer y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__hoedown_renderer_data(hoedown_renderer_data *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { void * *tmp = &p->opaque; (void)tmp; }
}
struct _cffi_align__hoedown_renderer_data { char x; hoedown_renderer_data y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "HOEDOWN_AUTOLINK_EMAIL", (void *)_cffi_const_HOEDOWN_AUTOLINK_EMAIL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_AUTOLINK_NONE", (void *)_cffi_const_HOEDOWN_AUTOLINK_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_AUTOLINK_NORMAL", (void *)_cffi_const_HOEDOWN_AUTOLINK_NORMAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_AUTOLINK", (void *)_cffi_const_HOEDOWN_EXT_AUTOLINK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_DISABLE_INDENTED_CODE", (void *)_cffi_const_HOEDOWN_EXT_DISABLE_INDENTED_CODE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_FENCED_CODE", (void *)_cffi_const_HOEDOWN_EXT_FENCED_CODE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_FOOTNOTES", (void *)_cffi_const_HOEDOWN_EXT_FOOTNOTES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_HIGHLIGHT", (void *)_cffi_const_HOEDOWN_EXT_HIGHLIGHT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_MATH", (void *)_cffi_const_HOEDOWN_EXT_MATH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_MATH_EXPLICIT", (void *)_cffi_const_HOEDOWN_EXT_MATH_EXPLICIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_NO_INTRA_EMPHASIS", (void *)_cffi_const_HOEDOWN_EXT_NO_INTRA_EMPHASIS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_QUOTE", (void *)_cffi_const_HOEDOWN_EXT_QUOTE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_SPACE_HEADERS", (void *)_cffi_const_HOEDOWN_EXT_SPACE_HEADERS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_STRIKETHROUGH", (void *)_cffi_const_HOEDOWN_EXT_STRIKETHROUGH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_SUPERSCRIPT", (void *)_cffi_const_HOEDOWN_EXT_SUPERSCRIPT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_TABLES", (void *)_cffi_const_HOEDOWN_EXT_TABLES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_EXT_UNDERLINE", (void *)_cffi_const_HOEDOWN_EXT_UNDERLINE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_ESCAPE", (void *)_cffi_const_HOEDOWN_HTML_ESCAPE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_HARD_WRAP", (void *)_cffi_const_HOEDOWN_HTML_HARD_WRAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_SKIP_HTML", (void *)_cffi_const_HOEDOWN_HTML_SKIP_HTML, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_TAG_CLOSE", (void *)_cffi_const_HOEDOWN_HTML_TAG_CLOSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_TAG_NONE", (void *)_cffi_const_HOEDOWN_HTML_TAG_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_TAG_OPEN", (void *)_cffi_const_HOEDOWN_HTML_TAG_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_HTML_USE_XHTML", (void *)_cffi_const_HOEDOWN_HTML_USE_XHTML, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_LIST_ORDERED", (void *)_cffi_const_HOEDOWN_LIST_ORDERED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_LI_BLOCK", (void *)_cffi_const_HOEDOWN_LI_BLOCK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_TABLE_ALIGNMASK", (void *)_cffi_const_HOEDOWN_TABLE_ALIGNMASK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_TABLE_ALIGN_CENTER", (void *)_cffi_const_HOEDOWN_TABLE_ALIGN_CENTER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_TABLE_ALIGN_LEFT", (void *)_cffi_const_HOEDOWN_TABLE_ALIGN_LEFT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_TABLE_ALIGN_RIGHT", (void *)_cffi_const_HOEDOWN_TABLE_ALIGN_RIGHT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HOEDOWN_TABLE_HEADER", (void *)_cffi_const_HOEDOWN_TABLE_HEADER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "hoedown_buffer_free", (void *)_cffi_f_hoedown_buffer_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 58), (void *)_cffi_d_hoedown_buffer_free },
  { "hoedown_buffer_grow", (void *)_cffi_f_hoedown_buffer_grow, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 109), (void *)_cffi_d_hoedown_buffer_grow },
  { "hoedown_buffer_new", (void *)_cffi_f_hoedown_buffer_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_hoedown_buffer_new },
  { "hoedown_buffer_puts", (void *)_cffi_f_hoedown_buffer_puts, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 61), (void *)_cffi_d_hoedown_buffer_puts },
  { "hoedown_document_free", (void *)_cffi_f_hoedown_document_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 124), (void *)_cffi_d_hoedown_document_free },
  { "hoedown_document_new", (void *)_cffi_f_hoedown_document_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 3), (void *)_cffi_d_hoedown_document_new },
  { "hoedown_document_render", (void *)_cffi_f_hoedown_document_render, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 127), (void *)_cffi_d_hoedown_document_render },
  { "hoedown_escape_html", (void *)_cffi_f_hoedown_escape_html, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 118), (void *)_cffi_d_hoedown_escape_html },
  { "hoedown_html_renderer_free", (void *)_cffi_f_hoedown_html_renderer_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 133), (void *)_cffi_d_hoedown_html_renderer_free },
  { "hoedown_html_renderer_new", (void *)_cffi_f_hoedown_html_renderer_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 8), (void *)_cffi_d_hoedown_html_renderer_new },
  { "hoedown_html_smartypants", (void *)_cffi_f_hoedown_html_smartypants, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 113), (void *)_cffi_d_hoedown_html_smartypants },
  { "hoedown_html_toc_renderer_new", (void *)_cffi_f_hoedown_html_toc_renderer_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 12), (void *)_cffi_d_hoedown_html_toc_renderer_new },
  { "hoedown_malloc", (void *)_cffi_f_hoedown_malloc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 51), (void *)_cffi_d_hoedown_malloc },
  { "misaka_get_renderer", (void *)_cffi_f_misaka_get_renderer, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 48), (void *)_cffi_d_misaka_get_renderer },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "data", offsetof(hoedown_buffer, data),
            sizeof(((hoedown_buffer *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 151) },
  { "size", offsetof(hoedown_buffer, size),
            sizeof(((hoedown_buffer *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "asize", offsetof(hoedown_buffer, asize),
             sizeof(((hoedown_buffer *)0)->asize),
             _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "unit", offsetof(hoedown_buffer, unit),
            sizeof(((hoedown_buffer *)0)->unit),
            _CFFI_OP(_CFFI_OP_NOOP, 1) },
  { "data_realloc", offsetof(hoedown_buffer, data_realloc),
                    sizeof(((hoedown_buffer *)0)->data_realloc),
                    _CFFI_OP(_CFFI_OP_NOOP, 153) },
  { "data_free", offsetof(hoedown_buffer, data_free),
                 sizeof(((hoedown_buffer *)0)->data_free),
                 _CFFI_OP(_CFFI_OP_NOOP, 162) },
  { "buffer_free", offsetof(hoedown_buffer, buffer_free),
                   sizeof(((hoedown_buffer *)0)->buffer_free),
                   _CFFI_OP(_CFFI_OP_NOOP, 162) },
  { "opaque", offsetof(hoedown_renderer, opaque),
              sizeof(((hoedown_renderer *)0)->opaque),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
  { "blockcode", offsetof(hoedown_renderer, blockcode),
                 sizeof(((hoedown_renderer *)0)->blockcode),
                 _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "blockquote", offsetof(hoedown_renderer, blockquote),
                  sizeof(((hoedown_renderer *)0)->blockquote),
                  _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "header", offsetof(hoedown_renderer, header),
              sizeof(((hoedown_renderer *)0)->header),
              _CFFI_OP(_CFFI_OP_NOOP, 158) },
  { "hrule", offsetof(hoedown_renderer, hrule),
             sizeof(((hoedown_renderer *)0)->hrule),
             _CFFI_OP(_CFFI_OP_NOOP, 160) },
  { "list", offsetof(hoedown_renderer, list),
            sizeof(((hoedown_renderer *)0)->list),
            _CFFI_OP(_CFFI_OP_NOOP, 155) },
  { "listitem", offsetof(hoedown_renderer, listitem),
                sizeof(((hoedown_renderer *)0)->listitem),
                _CFFI_OP(_CFFI_OP_NOOP, 155) },
  { "paragraph", offsetof(hoedown_renderer, paragraph),
                 sizeof(((hoedown_renderer *)0)->paragraph),
                 _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "table", offsetof(hoedown_renderer, table),
             sizeof(((hoedown_renderer *)0)->table),
             _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "table_header", offsetof(hoedown_renderer, table_header),
                    sizeof(((hoedown_renderer *)0)->table_header),
                    _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "table_body", offsetof(hoedown_renderer, table_body),
                  sizeof(((hoedown_renderer *)0)->table_body),
                  _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "table_row", offsetof(hoedown_renderer, table_row),
                 sizeof(((hoedown_renderer *)0)->table_row),
                 _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "table_cell", offsetof(hoedown_renderer, table_cell),
                  sizeof(((hoedown_renderer *)0)->table_cell),
                  _CFFI_OP(_CFFI_OP_NOOP, 157) },
  { "footnotes", offsetof(hoedown_renderer, footnotes),
                 sizeof(((hoedown_renderer *)0)->footnotes),
                 _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "footnote_def", offsetof(hoedown_renderer, footnote_def),
                    sizeof(((hoedown_renderer *)0)->footnote_def),
                    _CFFI_OP(_CFFI_OP_NOOP, 159) },
  { "blockhtml", offsetof(hoedown_renderer, blockhtml),
                 sizeof(((hoedown_renderer *)0)->blockhtml),
                 _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "autolink", offsetof(hoedown_renderer, autolink),
                sizeof(((hoedown_renderer *)0)->autolink),
                _CFFI_OP(_CFFI_OP_NOOP, 145) },
  { "codespan", offsetof(hoedown_renderer, codespan),
                sizeof(((hoedown_renderer *)0)->codespan),
                _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "double_emphasis", offsetof(hoedown_renderer, double_emphasis),
                       sizeof(((hoedown_renderer *)0)->double_emphasis),
                       _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "emphasis", offsetof(hoedown_renderer, emphasis),
                sizeof(((hoedown_renderer *)0)->emphasis),
                _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "underline", offsetof(hoedown_renderer, underline),
                 sizeof(((hoedown_renderer *)0)->underline),
                 _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "highlight", offsetof(hoedown_renderer, highlight),
                 sizeof(((hoedown_renderer *)0)->highlight),
                 _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "quote", offsetof(hoedown_renderer, quote),
             sizeof(((hoedown_renderer *)0)->quote),
             _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "image", offsetof(hoedown_renderer, image),
             sizeof(((hoedown_renderer *)0)->image),
             _CFFI_OP(_CFFI_OP_NOOP, 146) },
  { "linebreak", offsetof(hoedown_renderer, linebreak),
                 sizeof(((hoedown_renderer *)0)->linebreak),
                 _CFFI_OP(_CFFI_OP_NOOP, 149) },
  { "link", offsetof(hoedown_renderer, link),
            sizeof(((hoedown_renderer *)0)->link),
            _CFFI_OP(_CFFI_OP_NOOP, 146) },
  { "triple_emphasis", offsetof(hoedown_renderer, triple_emphasis),
                       sizeof(((hoedown_renderer *)0)->triple_emphasis),
                       _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "strikethrough", offsetof(hoedown_renderer, strikethrough),
                     sizeof(((hoedown_renderer *)0)->strikethrough),
                     _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "superscript", offsetof(hoedown_renderer, superscript),
                   sizeof(((hoedown_renderer *)0)->superscript),
                   _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "footnote_ref", offsetof(hoedown_renderer, footnote_ref),
                    sizeof(((hoedown_renderer *)0)->footnote_ref),
                    _CFFI_OP(_CFFI_OP_NOOP, 150) },
  { "math", offsetof(hoedown_renderer, math),
            sizeof(((hoedown_renderer *)0)->math),
            _CFFI_OP(_CFFI_OP_NOOP, 148) },
  { "raw_html", offsetof(hoedown_renderer, raw_html),
                sizeof(((hoedown_renderer *)0)->raw_html),
                _CFFI_OP(_CFFI_OP_NOOP, 147) },
  { "entity", offsetof(hoedown_renderer, entity),
              sizeof(((hoedown_renderer *)0)->entity),
              _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "normal_text", offsetof(hoedown_renderer, normal_text),
                   sizeof(((hoedown_renderer *)0)->normal_text),
                   _CFFI_OP(_CFFI_OP_NOOP, 156) },
  { "doc_header", offsetof(hoedown_renderer, doc_header),
                  sizeof(((hoedown_renderer *)0)->doc_header),
                  _CFFI_OP(_CFFI_OP_NOOP, 161) },
  { "doc_footer", offsetof(hoedown_renderer, doc_footer),
                  sizeof(((hoedown_renderer *)0)->doc_footer),
                  _CFFI_OP(_CFFI_OP_NOOP, 161) },
  { "opaque", offsetof(hoedown_renderer_data, opaque),
              sizeof(((hoedown_renderer_data *)0)->opaque),
              _CFFI_OP(_CFFI_OP_NOOP, 55) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "hoedown_buffer", 140, _CFFI_F_CHECK_FIELDS,
    sizeof(hoedown_buffer), offsetof(struct _cffi_align__hoedown_buffer, y), 0, 7 },
  { "hoedown_document", 141, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "hoedown_renderer", 143, _CFFI_F_CHECK_FIELDS,
    sizeof(hoedown_renderer), offsetof(struct _cffi_align__hoedown_renderer, y), 7, 36 },
  { "hoedown_renderer_data", 144, _CFFI_F_CHECK_FIELDS,
    sizeof(hoedown_renderer_data), offsetof(struct _cffi_align__hoedown_renderer_data, y), 43, 1 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "hoedown_autolink_type", 18, _cffi_prim_int(sizeof(hoedown_autolink_type), ((hoedown_autolink_type)-1) <= 0),
    "HOEDOWN_AUTOLINK_NONE,HOEDOWN_AUTOLINK_NORMAL,HOEDOWN_AUTOLINK_EMAIL" },
  { "hoedown_extensions", 5, _cffi_prim_int(sizeof(hoedown_extensions), ((hoedown_extensions)-1) <= 0),
    "HOEDOWN_EXT_TABLES,HOEDOWN_EXT_FENCED_CODE,HOEDOWN_EXT_FOOTNOTES,HOEDOWN_EXT_AUTOLINK,HOEDOWN_EXT_STRIKETHROUGH,HOEDOWN_EXT_UNDERLINE,HOEDOWN_EXT_HIGHLIGHT,HOEDOWN_EXT_QUOTE,HOEDOWN_EXT_SUPERSCRIPT,HOEDOWN_EXT_MATH,HOEDOWN_EXT_NO_INTRA_EMPHASIS,HOEDOWN_EXT_SPACE_HEADERS,HOEDOWN_EXT_MATH_EXPLICIT,HOEDOWN_EXT_DISABLE_INDENTED_CODE" },
  { "hoedown_html_flags", 9, _cffi_prim_int(sizeof(hoedown_html_flags), ((hoedown_html_flags)-1) <= 0),
    "HOEDOWN_HTML_SKIP_HTML,HOEDOWN_HTML_ESCAPE,HOEDOWN_HTML_HARD_WRAP,HOEDOWN_HTML_USE_XHTML" },
  { "hoedown_html_tag", 142, _cffi_prim_int(sizeof(hoedown_html_tag), ((hoedown_html_tag)-1) <= 0),
    "HOEDOWN_HTML_TAG_NONE,HOEDOWN_HTML_TAG_OPEN,HOEDOWN_HTML_TAG_CLOSE" },
  { "hoedown_list_flags", 74, _cffi_prim_int(sizeof(hoedown_list_flags), ((hoedown_list_flags)-1) <= 0),
    "HOEDOWN_LIST_ORDERED,HOEDOWN_LI_BLOCK" },
  { "hoedown_table_flags", 85, _cffi_prim_int(sizeof(hoedown_table_flags), ((hoedown_table_flags)-1) <= 0),
    "HOEDOWN_TABLE_ALIGN_LEFT,HOEDOWN_TABLE_ALIGN_RIGHT,HOEDOWN_TABLE_ALIGN_CENTER,HOEDOWN_TABLE_ALIGNMASK,HOEDOWN_TABLE_HEADER" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "hoedown_autolink_type", 18 },
  { "hoedown_buffer", 140 },
  { "hoedown_document", 141 },
  { "hoedown_extensions", 5 },
  { "hoedown_free_callback", 162 },
  { "hoedown_html_flags", 9 },
  { "hoedown_html_tag", 142 },
  { "hoedown_list_flags", 74 },
  { "hoedown_realloc_callback", 153 },
  { "hoedown_renderer", 143 },
  { "hoedown_renderer_data", 144 },
  { "hoedown_table_flags", 85 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  45,  /* num_globals */
  4,  /* num_struct_unions */
  6,  /* num_enums */
  12,  /* num_typenames */
  NULL,  /* no includes */
  164,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__hoedown(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__hoedown(void) { return NULL; }
#  else
     init_hoedown(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__hoedown(void)
{
  return _cffi_init("misaka._hoedown", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_hoedown(void)
{
  _cffi_init("misaka._hoedown", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
